%==========================================================================
%
%   prioritySampling.m
%
%   Authors: SUMO Lab Team
%   Version: 1.0
%   Copyright: 2017
%   
%   When referring to ALBATROS please make reference to the corresponding publication:
%   
%   Van Steenkiste T., J. van der Herten, D. Deschrijver and T. Dhaene.
%   "ABLATROS: Adaptive Line-Based Sampling Trajectories for Sequential
%   Measurements". Engineering with Computers.
%
%==========================================================================
%
%   SIGNATURE:
%   projection = projectPointToLine( A, B, point )
%
%==========================================================================
%
%   PURPOSE:
%   Project a point onto the line specified by A and B
%
%   INPUT:
%   A: point of the line
%   B: point of the line
%   point: point to be projected onto AB
%  
%   OUTPUT:
%   projection: projection of point onto AB
%   %==========================================================================

function projection = projectPointToLine( A, B, point )
    AB = dot(B-A,B-A);
    if AB == 0
        projection = A;
    else
       t = dot(point-A,B-A)/AB;
       if t < 0
           projection = A;
       elseif t > 1
           projection = B;
       else
           projection = A + t * (B-A);
       end
    end
end

